/**
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 */

import { createClientAsync, logSoapError } from '../../soap.js'

const OXResellerContextService = createClientAsync('OXResellerContextService').then(client => client)

export async function create (data) {
  return await (await OXResellerContextService).createAsync(data)
}

export async function remove (contextId) {
  return !!await (await OXResellerContextService).deleteAsync({
    ctx: { id: contextId }
  }).then(() => true).catch(logSoapError)
}

export async function change (ctx) {
  return await (await OXResellerContextService).changeAsync({ ctx })
}

export async function get (id) {
  return await (await OXResellerContextService).getDataAsync({ ctx: { id } })
}

export async function getModuleAccess (id) {
  return await (await OXResellerContextService).getModuleAccessAsync({ ctx: id })
}

export async function changeModuleAccess (id, access) {
  const currentAccess = await getModuleAccess(id)

  return await (await OXResellerContextService).changeModuleAccessAsync({ ctx: { id }, access: { ...currentAccess, ...access } })
}

export async function listAll (data) {
  return await (await OXResellerContextService).listAllAsync(data)
}
