/**
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 */

import { createClientAsync, logSoapError } from '../../soap.js'

const OXResellerUserService = createClientAsync('OXResellerUserService').then(client => client)

export async function remove (contextId, userId) {
  return !!await (await OXResellerUserService).deleteAsync({
    ctx: { id: contextId },
    user: { id: userId }
  }).then(() => true).catch(logSoapError)
}

/**
 * This function changes the context with the specified ID.
 * @param {Object} context The context of the user to be changed.
 * @param {Object} usrdata The user to change.
 * @returns {Promise<void>}
 */
export async function change (context, usrdata) {
  return await (await OXResellerUserService).changeAsync({
    ctx: { id: context.id },
    usrdata,
    auth: { login: context.admin.name, password: context.admin.password }
  })
}

export async function get (data) {
  return await (await OXResellerUserService).getDataAsync(data)
}

export async function getModuleAccess (context, userId) {
  return await (await OXResellerUserService).getModuleAccessAsync({
    ctx: { id: context.id },
    user: { id: userId },
    auth: { login: context.admin.name, password: context.admin.password }
  }).then(
    (res) => res
  )
}

export async function changeByModuleAccess (context, userId, currentAccess, moduleAccess) {
  return await (await OXResellerUserService).changeByModuleAccessAsync({
    ctx: { id: context.id },
    moduleAccess: Object.assign({}, currentAccess, moduleAccess),
    user: { id: userId },
    auth: { login: context.admin.name, password: context.admin.password }
  })
}

export async function changeByModuleAccessName (context, userId, accessCombinationName) {
  return await (await OXResellerUserService).changeByModuleAccessNameAsync({
    ctx: { id: context.id },
    access_combination_name: accessCombinationName,
    user: { id: userId },
    auth: { login: context.admin.name, password: context.admin.password }
  }).catch(error => console.error('Module access change error: ', error))
}

export async function createByModuleAccessName (context, usrdata) {
  return await (await OXResellerUserService).createByModuleAccessNameAsync({
    ctx: { id: context.id },
    usrdata,
    access_combination_name: 'all',
    auth: { login: context.admin.name, password: context.admin.password }
  })
}

export async function listAll (data) {
  return await (await OXResellerUserService).listAllAsync(data)
}
