import { createClientAsync } from '../soap.js'

const OXSecondaryAccountService = createClientAsync('OXSecondaryAccountService').then(client => client)

/**
 * Creates a secondary account using the OX Secondary Account Service
 * @async
 * @param {Object} accountData - The data for the secondary account to be created
 * @param {Object} context - The context object where the account will be created
 * @param {Array<Object>} users - Array of users to associate with the secondary account
 * @param {Array<Object>} groups - Array of groups to associate with the secondary account
 * @returns {Promise<Object>} The created secondary account object
 * @throws {Error} If the account creation fails
 */
export async function create (accountData, context, users = [], groups = []) {
  return await (await OXSecondaryAccountService).createAsync({
    accountDataOnCreate: accountData,
    context: { id: context.id },
    users: users || [],
    auth: context.admin
  })
}

export async function list (context) {
  return await (await OXSecondaryAccountService).listAsync({
    context: { id: context.id },
    auth: context.admin
  })
}
export async function remove (primaryAddress, context, users, groups) {
  return await (await OXSecondaryAccountService).deleteAsync({
    primaryAddress,
    context: { id: context.id },
    users,
    auth: context.admin
  })
}

export async function update (primaryAddress, accountData, context, users, groups) {
  return await (await OXSecondaryAccountService).updateAsync({
    primaryAddress,
    accountDataUpdate: accountData,
    context: { id: context.id },
    users,
    groups,
    auth: context.admin
  })
}
